@@ -259,12 +259,16 @@ def pbn2html(pbn_file):
             # _: ./pbn2html.py
             #for item, value in os.environ.items():
             #    print('{}: {}'.format(item, value))
-            if "pbn2html.py" in os.environ.get("_"):
-                template = open("template.html", "r",encoding="utf-8").read()
-                src = Template(template)
-            else:
+            if sys.platform.startswith('win'):
                 template = pkgutil.get_data(__name__,'template.html')
                 src = Template(template.decode('utf-8'))
+            else:
+                if "pbn2html.py" in os.environ.get("_"):
+                    template = open("template.html", "r",encoding="utf-8").read()
+                    src = Template(template)
+                else:
+                    template = pkgutil.get_data(__name__,'template.html')
+                    src = Template(template.decode('utf-8'))
 
             result += src.safe_substitute(all)
         except ParseError as error:
