@@ -3,8 +3,8 @@
 import sys
 import re
 import markdown
-from .xin2pbn import xin2pbn
-from .pbn2html import pbn2html
+from xin2pbn import xin2pbn
+from pbn2html import pbn2html
 
 # it is to 
 # 1. generate html from markdown
@@ -65,8 +65,8 @@ def convert(mdfile):
     generate_html(mdfile,orig_htmlfile)
     # updtae link and color of suit
     update_html(orig_htmlfile, htmlfile)
-    # generate pbn
-    xin2pbn.generate_pbn_from_html([htmlfile])
+    # generate one big pbn only
+    xin2pbn.generate_pbn_from_html([htmlfile], False)
     # generate pbn html file
     pbn2html.pbn2html(pbnfile)
 
